==> prayer-1.0.12.tar.gz: prayer-1.0.12/prayer/cmd_vaclog.c <==
/* $Cambridge: hermes/src/prayer/prayer/cmd_vaclog.c,v 1.2 2003/05/21 10:10:55 dpc22 Exp $ */
/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2002 */
/* See the file NOTICE for conditions of use and distribution. */

#include "prayer_session.h"

void cmd_vaclog(struct session *session)
{
    struct account *account = session->account;
    struct request *request = session->request;
    struct buffer *b = request->write_buffer;
    char *vaclog;

    if (request->method == POST) {
        request_decode_post(request);

        if (assoc_lookup(request->form, "sub_clear")) {
            account_vaclog_clear(session->account, request->pool);
            session_message(session, "Cleared vacation log");
        }
        session_redirect(session, request, "manage");
        return;
    }

    if (!(vaclog = account_vaclog_fetch(session->account, request->pool))) {
        char *msg = account_fetch_message(account);
        struct buffer *b = request->write_buffer;

        /* Title Bar */
        html_start(session, b, "Vacation Log");
        html_banner_toolbar(session, b, "vaclog", 0);

        /* Title line */
        bputs(b, "<h2 align=\"center\">Vacation Log</h2>" CRLF);

        bputs(b, "<b>Error:</b> ");
        if (msg)
            html_quote_string(b, msg);
        else
            bputs(b, "Unable to check mail processing status");
        bputs(b, "" CRLF);

        /* Form body */
        html_form_start(session, b, "POST", "vaclog");

        /* Cancel button */
        bputs(b, "<table>" CRLF);
        bputs(b, "<tr>" CRLF);
        html_form_table_submit(b, "sub_cancel", "Back to Options screen");
        bputs(b, "</tr>" CRLF);
        bputs(b, "</table>" CRLF);
        html_form_end(b);

        html_end(b);
        response_html(request, 200);
        return;
    }

    /* Title bar */
    html_start(session, b, "Vacation Log");
    html_banner_toolbar(session, b, "vaclog", 0);

    /* Title line */
    bputs(b, "<h2 align=\"center\">Vacation log </h2>" CRLF);

    if (vaclog && vaclog[0]) {
        bputs(b, "<pre>" CRLF);
        html_quote_string(b, vaclog);
        bputs(b, "</pre>" CRLF);
    } else
        bputs(b, "No vacation log at this time");

    /* Form body */
    html_form_start(session, b, "POST", "vaclog");
    html_form_submit(b, "sub_back", "Back to Options Screen");
    html_form_submit(b, "sub_clear", "Clear vacation log");
    html_form_end(b);

    html_end(b);
    response_html(request, 200);        /* Success */
}

==> prayer-1.0.16.tar.gz: prayer-1.0.16/prayer/cmd_vaclog.c <==
/* $Cambridge: hermes/src/prayer/prayer/cmd_vaclog.c,v 1.6 2005/08/10 09:48:34 dpc22 Exp $ */
/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2002 */
/* See the file NOTICE for conditions of use and distribution. */

#include "prayer_session.h"

void cmd_vaclog(struct session *session)
{
    struct account *account = session->account;
    struct request *request = session->request;
    struct buffer *b = request->write_buffer;
    char *vaclog;

    if (request->method == POST) {
        request_decode_post(request);

        if (assoc_lookup(request->form, "sub_clear")) {
            if (account_vaclog_clear(session->account, request->pool)) {
                session_message(session, "Cleared vacation log");
            } else {
                char *msg = account_fetch_message(session->account);

                session_message(session,
                                "Failed to clear vacation log: %s", msg);
                session_log(session,
                            "[cmd_vaclog] Failed to clear vacation log: %s",
                            msg);
            }
        }
        session_redirect(session, request, "manage");
        return;
    }

    if (!(vaclog = account_vaclog_fetch(account, request->pool))) {
        char *msg = account_fetch_message(account);
        struct buffer *b = request->write_buffer;

        /* Title Bar */
        html_start(session, b, "Vacation Log");
        html_banner_toolbar(session, b, "vaclog", 0);

        /* Title line */
        bputs(b, "<h2 align=\"center\">Vacation Log</h2>" CRLF);

        bputs(b, "<b>Error:</b> ");
        if (msg) {
            html_quote_string(b, msg);
            session_log(session, "[cmd_vaclog] %s", msg);
        } else
            bputs(b, "Unable to check mail processing status");
        bputs(b, "" CRLF);

        /* Form body */
        html_form_start(session, b, "POST", "vaclog");

        /* Cancel button */
        bputs(b, "<table>" CRLF);
        bputs(b, "<tr>" CRLF);
        html_form_table_submit(b, "sub_cancel", "Back to Options screen");
        bputs(b, "</tr>" CRLF);
        bputs(b, "</table>" CRLF);
        html_form_end(b);

        html_end(b);
        response_html(request, 200);
        return;
    }

    /* Title bar */
    html_start(session, b, "Vacation Log");
    html_banner_toolbar(session, b, "vaclog", 0);

    /* Title line */
    bputs(b, "<h2 align=\"center\">Vacation log </h2>" CRLF);

    if (vaclog && vaclog[0]) {
        bputs(b, "<pre>" CRLF);
        html_quote_string(b, vaclog);
        bputs(b, "</pre>" CRLF);
    } else
        bputs(b, "No vacation log at this time");

    /* Form body */
    html_form_start(session, b, "POST", "vaclog");
    html_form_submit(b, "sub_back", "Back to Options Screen");
    html_form_submit(b, "sub_clear", "Clear vacation log");
    html_form_end(b);

    html_end(b);
    response_html(request, 200);        /* Success */
}
